@@ -22,7 +22,6 @@ export class Patient extends Model {
   declare dateOfDeath?: string;
   declare sex: string;
   declare email?: string;
-  declare villageId?: string;
   declare visibilityStatus?: string;
   declare mergedIntoId?: string;
   declare additionalData?: PatientAdditionalData[];
@@ -111,6 +110,12 @@ export class Patient extends Model {
       as: 'markedForSyncFacilities',
     });
 
+    this.belongsToMany(models.Prescription, {
+      through: models.PatientOngoingPrescription,
+      foreignKey: 'patientId',
+      as: 'ongoingPrescriptions',
+    });
+
     this.hasMany(models.PatientFieldValue, {
       foreignKey: 'patientId',
       as: 'fieldValues',
@@ -121,11 +126,6 @@ export class Patient extends Model {
       as: 'patientProgramRegistrations',
     });
 
-    this.hasMany(models.PatientProgramRegistrationCondition, {
-      foreignKey: 'patientId',
-      as: 'patientProgramRegistrationConditions',
-    });
-
     this.hasMany(models.PatientContact, {
       foreignKey: 'patientId',
       as: 'contacts',
